************
DeltaMetrics
************

.. image:: https://github.com/DeltaRCM/DeltaMetrics/workflows/build/badge.svg
  :target: https://github.com/DeltaRCM/DeltaMetrics/actions

.. image:: https://codecov.io/gh/DeltaRCM/DeltaMetrics/branch/develop/graph/badge.svg
  :target: https://codecov.io/gh/DeltaRCM/DeltaMetrics

*DeltaMetrics* is a Python package for manipulating depositional system data cubes.
The package has robust objects and routines designed to help organize, visualize, and analyze topography and sedimentological timeseries data.
*DeltaMetrics* works especially well with data from deltaic systems (e.g., the `pyDeltaRCM numerical model <https://github.com/DeltaRCM/pyDeltaRCM>`_  and laboratory delta experiments).

`Full documentation here <https://deltarcm.org/DeltaMetrics/index.html>`_.


.. figure:: https://deltarcm.org/DeltaMetrics/_images/cover.png

  A view of bed elevation on a modeled deltaic deposit in ``Planform``, and a cross ``StrikeSection`` view of the timing of sediment deposition in stratigraphy.
